@@ -319,7 +319,7 @@ class GasPacket(ImazuPacket):
 
     def make_change_valve_close(self) -> bytearray:
         """Valve close packet Make"""
-        return super().make_change(ValueType.BOOL, int(str(GasPacket.Valve.CLOSE), 16))
+        return super().make_change(ValueType.VALVE, int(str(GasPacket.Valve.CLOSE.value), 16))
 
 
 # class AcPacket(ImazuPacket):
@@ -419,14 +419,6 @@ class AwayPacket(ImazuPacket):
         """Scan packet Make"""
         return super()._make_scan(ValueType.BOOL)
 
-    def make_change_power(self, power: Power) -> bytearray:
-        """Power packet Make"""
-        return super().make_change(ValueType.BOOL, int(str(power.value), 16))
-
-    def make_change_valve(self, valve: Valve) -> bytearray:
-        """Vavle packet Make"""
-        return super().make_change(ValueType.BOOL, int(str(valve.value), 16))
-
 
 class FanPacket(ImazuPacket):
     """Imazu fan packet
